==> knowledgeroot_0.9.7.3.orig.tar.gz: knowledgeroot-0.9.7.3/system/language/lang_de.php <==
<?php

$languagetoken = array(
	"de" => array(
		"path" => "Pfad",
		"editcontent" => "Inhalt bearbeiten",
		"delcontent" => "Inhalt l&ouml;schen",
		"addfile" => "Datei Anh&auml;ngen",
		"add" => "Anh&auml;ngen",
		"newpage" => "Neue Seite anlegen",
		"autoopen" => "auf neue Seite gehen",
		"delpage" => "Seite l&ouml;schen",
		"delpageask" => "Seite wirklich l&ouml;schen?",
		"delpagefailed" => "Konnte Seite nicht l&ouml;schen aufgrund von Abh&auml;ngigkeiten. Es k&ouml;nnte Inhalt auf dieser Seite liegen.",
		"delete" => "Wirklich l&ouml;schen?",
		"newcontent" => "Neuen Inhalt anlegen",
		"renamepage" => "Seite bearbeiten",
		"save" => "Speichern",
		"saveandclose" => "Speichern und Schliessen",
		"close" => "Schliessen",
		"rename" => "Umbenennen",
		"back" => "Zur&uuml;ck",
		"del" => "L&ouml;schen",
		"nocontent" => "Keine Inhalte vorhanden.",
		"user" => "Benutzer",
		"search" => "Suche",
		"searchgo" => "GO",
		"nothingfound" => "Es wurde nichts gefunden.",
		"searchcontent" => "Inhalt",
		"searchmenu" => "Men&uuml;",
		"searchfiles" => "Dateien",
		"searchfor" => "Suchen nach",
		"searchshow" => "zeigen",
		"top" => "Nach oben",
		"topdescription" => "Nach oben",
		"movepage" => "Seite verschieben",
		"movecontent" => "Inhalt verschieben",
		"moveto" => "Verschieben nach",
		"welcome" => "Willkommen zu Knowledgeroot",
		"emptyroot" => "Der Name darf nicht leer sein!",

		"movecontentup" => "nach oben verschieben",
		"movecontentdown" => "nach unten verschieben",
		"contentmoved" => "Inhalt wurde verschoben",

		"version" => "Version",

		"nouploadfolder" => "Keinen Ordner f&uuml;r Uploads gefunden!",

		"tree" => array(
			"expand" => "Aufklappen",
			"collapse" => "Einklappen",
			"reload" => "Neuladen",
			"hidetree" => "Men&uuml; verstecken",
			"showtree" => "Men&uuml; anzeigen",
			"closemenu" => "Men&uuml; l&ouml;sen",
			"showmenu" => "Men&uuml; fixieren",
		),

		"messagebox" => array(
			"loading" => "Lade...",
		),

		"menu" => array(
			"roots" => "Roots",
			"user" => "Benutzer",
			"options" => "Optionen",
			"logout" => "Logout",
			"login" => "Login",
		),

		"loginform" => array(
			"title" => "Login",
			"user" => "Benutzer",
			"password" => "Passwort",
			"submit" => "Einloggen",
		),

		"rootform" => array(
			"title" => "Root erstellen",
			"name" => "Name",
			"submit" => "Erstellen",
		),

		"rightpanel" => array(
			"user" => "Benutzer",
			"group" => "Gruppe",
			"userrights" => "Benutzerrechte",
			"grouprights" => "Gruppenrechte",
			"otherrights" => "Sonstige",
			"recursiv" => "Rekursiv setzen",
		),

		"optionform" => array(
			"title" => "Optionen",
			"subtitle" => "Optionen &auml;ndern",
			"newpassword" => "Neues Passwort",
			"newpassword2" => "Passwort best&auml;tigen",
			"submit" => "Speichern",
			"changed" => "Passwort wurde ge&auml;ndert",
			"failed" => "Passwort konnte nicht ge&auml;ndert werden",
			"theme" => "Theme",
			"themechanged" => "Theme wurde ge&auml;ndert",
			"language" => "Sprache",
			"languagechanged" => "Sprache ge&auml;ndert",
		),

		"userform" => array(
			"usertitle" => "Benutzer",
			"adduser" => "Benutzer hinzuf&uuml;gen",
			"username" => "Name",
			"defaultgroup" => "Standardgruppe",
			"defaultrights" => "Standardrechte",
			"admin" => "Administrator",
			"rightedit" => "Rechte editierbar",
			"enabled" => "Freigeschaltet",
			"action" => "Aktion",
			"edit" => "Bearbeiten",
			"delete" => "L&ouml;schen",
			"theme" => "Theme",

			"grouptitle" => "Gruppen",
			"addgroup" => "Gruppe hinzuf&uuml;gen",
			"groupname" => "Name",

			"newuser" => "Neuer Benutzer",
			"edituser" => "Benutzer bearbeiten",
			"editgroup" => "Gruppe editieren",
			"password" => "Passwort",
			"groups" => "Gruppen",
			"submit" => "Speichern",
			"user" => "Benutzer",
			"group" => "Gruppe",
			"others" => "Sonstige",

			"deluserask" => "Benutzer wirklich l&ouml;schen?",
			"delgroupask" => "Gruppe wirklich l&ouml;schen?",
		),

		"email" => array(
			"notification" => "Knowledgeroot Mitteilung",
			"pathofmodification" => "Pfad der &Auml;nderung",
			"content" => "Inhalt auf der Seite",
			"file" => "Datei",
			"page" => "Seite",
			"was" => "wurde",
			"created" => "erstellt",
			"edited" => "bearbeitet",
			"deleted" => "gel&ouml;scht",
			"moved" => "bewogen",
			"errormessage" => "EMail Mitteilung konnte nicht gesendet werden",
		),

		"yes" => "Ja",
		"no" => "Nein",
		"readwrite" => "Lesen+Schreiben",
		"read" => "Lesen",
		"norights" => "Keine",
	),
);

?>

==> knowledgeroot_0.9.8.5.orig.tar.gz: knowledgeroot-0.9.8.5/system/language/lang_de.php <==
<?php

$languagetoken = array(
	"de" => array(
		"path" => "Pfad",
		"editcontent" => "Inhalt bearbeiten",
		"delcontent" => "Inhalt l&ouml;schen",
		"contenthistory" => "Historie",
		"addfile" => "Datei Anh&auml;ngen",
		"add" => "Anh&auml;ngen",
		"newpage" => "Neue Seite anlegen",
		"newpagename" => "Seitenname",
		"newpagealias" => "Seitenalias",
		"delpage" => "Seite l&ouml;schen",
		"delpageask" => "Seite wirklich l&ouml;schen?",
		"delpagefailed" => "Konnte Seite nicht l&ouml;schen aufgrund von Abh&auml;ngigkeiten. Es k&ouml;nnte Inhalt auf dieser Seite liegen.",
		"delete" => "Wirklich l&ouml;schen?",
		"newcontent" => "Neuen Inhalt anlegen",
		"renamepage" => "Seite bearbeiten",
		"save" => "Speichern",
		"saveandclose" => "Speichern und Schliessen",
		"close" => "Schliessen",
		"contenttitle" => "Inhaltstitel (optional)",
		"collapseexpandcontent" => "Inhalt ein-/aufklappen",
		"lastmodifiedby" => "Letzte &Auml;nderung von",
		"guest" => "Gast",
		"on" => "am",
		"rename" => "Umbenennen",
		"back" => "Zur&uuml;ck",
		"del" => "L&ouml;schen",
		"nocontent" => "Keine Inhalte vorhanden.",
		"user" => "Benutzer",
		"search" => "Suche",
		"searchgo" => "GO",
		"nothingfound" => "Es wurde nichts gefunden.",
		"searchcontent" => "Inhalt",
		"searchmenu" => "Men&uuml;",
		"searchfiles" => "Dateien",
		"searchfor" => "Suchen nach",
		"searchshow" => "zeigen",
		"top" => "Nach oben",
		"topdescription" => "Nach oben",
		"movepage" => "Seite verschieben",
		"movecontent" => "Inhalt verschieben",
		"moveto" => "Verschieben nach",
		"movetoroot" => "Als Root erstellen",
		"moveclose" => "Fenster schliessen",
		"welcome" => "Willkommen zu Knowledgeroot",
		"emptyroot" => "Der Name darf nicht leer sein!",
		"movecontentup" => "nach oben verschieben",
		"movecontentdown" => "nach unten verschieben",
		"contentmoved" => "Inhalt wurde verschoben",
		"version" => "Version",
		"nouploadfolder" => "Keinen Ordner f&uuml;r Uploads gefunden!",
		"maxfilesize" => "Datei kann nicht hinzugef&uuml;gt werden da sie zu gro&szlig; ist!",
		"editpageform" => array(
			"title" => "Seite bearbeiten",
			"description" => "Hier k&ouml;nnen Sie die Seite umbenennen oder ihre Rechte ver&auml;ndern.",
			"name" => "Seitenname",
			"collapsecontent" => "Inhalt beim &ouml;ffnen der Seite eingeklappt darstellen?",
			"alias" => "Seitenalias",
			"button" => "&Auml;nderungen Speichern",
		), 
		"createpageform" => array(
			"title" => "Seite erstellen",
			"description" => "Hier k&ouml;nnen Sie eine neue Seite erstellen.",
			"name" => "Seitenname",
			"alias" => "Seitenalias",
			"button" => "Seite anlegen",
			"autoopen" => "auf neue Seite gehen",
		), 
		"tree" => array(
			"expand" => "Aufklappen",
			"collapse" => "Einklappen",
			"reload" => "Neuladen",
			"hidetree" => "Men&uuml; verstecken",
			"showtree" => "Men&uuml; anzeigen",
			"closemenu" => "Men&uuml; l&ouml;sen",
			"showmenu" => "Men&uuml; fixieren",
		), 
		"messagebox" => array(
			"loading" => "Lade...",
			"warning" => "Ein anderer Benutzer editiert diesen Text bereits!",
		), 
		"menu" => array(
			"roots" => "Roots",
			"user" => "Benutzer",
			"options" => "Optionen",
			"logout" => "Logout",
			"login" => "Login",
		), 
		"loginform" => array(
			"title" => "Login",
			"user" => "Benutzer",
			"password" => "Passwort",
			"submit" => "Einloggen",
			"loginfailed" => "Sie haben einen falschen Benutzer oder ein falsches Passwort verwendet!",
			"loginfailedtime" => "Sie k&ouml;nnen sich erst wieder nach #RELOGINDELAY# Sekunden erneut anmelden!",
			"loginfailedblock" => "Der Account wurde wegen zu vieler fehlerhafter Loginversuchen dauerhaft gesperrt!",
		), 
		"rootform" => array(
			"title" => "Root erstellen",
			"name" => "Name",
			"submit" => "Erstellen",
			"alias" => "Alias",
		), 
		"rightpanel" => array(
			"user" => "Benutzer",
			"group" => "Gruppe",
			"userrights" => "Benutzerrechte",
			"grouprights" => "Gruppenrechte",
			"otherrights" => "Sonstige",
			"recursiv" => "Rekursiv setzen",
			"pagerights" => "Seitenrechte",
			"pagerightsforsubpages" => "Vererbbare Rechte",
			"enablesubinheritrights" => "Vererbbare Rechte f&uuml;r Unterseiten und Inhalte aktivieren",
			"enablesubinheritrightsenabled" => "Editieren der vererbten Rechte erlauben",
			"disablesubinheritrights" => "Vererbbare Rechte f&uuml;r Unterseiten und Inhalte abschalten",
		), 
		"optionform" => array(
			"title" => "Optionen",
			"subtitle" => "Optionen &auml;ndern",
			"newpassword" => "Neues Passwort",
			"newpassword2" => "Passwort best&auml;tigen",
			"submit" => "Speichern",
			"changed" => "Passwort wurde ge&auml;ndert!",
			"failed" => "Passwort konnte nicht ge&auml;ndert werden!",
			"theme" => "Theme",
			"themechanged" => "Theme wurde ge&auml;ndert.",
			"language" => "Sprache",
			"languagechanged" => "Sprache ge&auml;ndert.",
		), 
		"userform" => array(
			"usertitle" => "Benutzer",
			"adduser" => "Benutzer hinzuf&uuml;gen",
			"username" => "Name",
			"defaultgroup" => "Standardgruppe",
			"defaultrights" => "Standardrechte",
			"admin" => "Administrator",
			"rightedit" => "Rechte editierbar",
			"enabled" => "Freigeschaltet",
			"action" => "Aktion",
			"edit" => "Bearbeiten",
			"delete" => "L&ouml;schen",
			"theme" => "Theme",
			"grouptitle" => "Gruppen",
			"addgroup" => "Gruppe hinzuf&uuml;gen",
			"groupname" => "Name",
			"delgroupfail" => "Gruppe konnte nicht gel&ouml;scht werden da sie als Standardgruppe verwendet wird!",
			"delgroupsuccess" => "Gruppe wurde gel&ouml;scht!",
			"newuser" => "Neuer Benutzer",
			"edituser" => "Benutzer bearbeiten",
			"editgroup" => "Gruppe editieren",
			"password" => "Passwort",
			"groups" => "Gruppen",
			"submit" => "Speichern",
			"user" => "Benutzer",
			"group" => "Gruppe",
			"others" => "Sonstige",
			"deluserask" => "Benutzer wirklich l&ouml;schen?",
			"delgroupask" => "Gruppe wirklich l&ouml;schen?",
			"delusersuccess" => "Benutzer wurde gel&ouml;scht!",
		), 
		"email" => array(
			"notification" => "Knowledgeroot Mitteilung",
			"pathofmodification" => "Pfad der &Auml;nderung",
			"content" => "Inhalt auf der Seite",
			"file" => "Datei",
			"page" => "Seite",
			"was" => "wurde",
			"created" => "erstellt",
			"edited" => "bearbeitet",
			"deleted" => "gel&ouml;scht",
			"moved" => "bewogen",
			"action" => "Aktion",
			"errormessage" => "EMail Mitteilung konnte nicht gesendet werden",
			"author" => "Author",
			"date" => "Datum",
		), 
		"yes" => "Ja",
		"no" => "Nein",
		"readwrite" => "Lesen+Schreiben",
		"read" => "Lesen",
		"norights" => "Keine",
	), 
);

?>
